from django.template import Library
from cms_lite.utils import get_cms_pages

register = Library()


@register.assignment_tag
def list_cms_pages(directory=None):
    return get_cms_pages(sub_dirs=[directory] if directory else [])



from django.conf.urls import patterns, url

urlpatterns = patterns(
    "cms_lite.views",
    url(r"^(?P<name>)?$", "render_template", name="cms_lite_page"),
    url(r"^(?P<name>(\w[\w\/\-]*\w|\w))/$", "render_template", name="cms_lite_page"),
)



from cms_lite import forms
from django.contrib import messages
from django.core.urlresolvers import reverse
from django.http import Http404
from django.shortcuts import redirect, render_to_response
from django.template import RequestContext, TemplateDoesNotExist
from django.template.loaders.filesystem import Loader
from django.views.decorators.http import require_http_methods
import codecs
import os


@require_http_methods(["GET", "POST"])
def render_template(request, name="index"):
    if not name:
        name="index"
    if "_" in name:
        return redirect(
            reverse(
                "cms_lite_page",
                args=[name.replace("_", "-")],
            ),
            permanent=True,
        )
    try:
        if name.startswith("-"):
            raise TemplateDoesNotExist()
        filename = os.path.join("cms_lite", name.replace("-", "_") + ".html")
        cms_can_edit = request.user.is_superuser
        if "edit" in request.REQUEST and cms_can_edit:
            source, abspath = Loader().load_template_source(filename)
            form = forms.CmsPageForm(data=request.POST or None)
            if form.is_valid():
                with codecs.open(abspath, encoding="utf-8", mode="w") as f:
                    f.write(form.cleaned_data["source"])
                messages.success(request, "CMS page updated")
                return redirect(request.META.get("PATH_INFO"))
            else:
                form.initial["source"] = source
                return render_to_response(
                    "cms_lite/_edit.html",
                    context_instance=RequestContext(request, {
                        "cms_can_edit": cms_can_edit,
                        "form": form,
                    }),
                )
        else:
            return render_to_response(
                filename,
                context_instance=RequestContext(request, {
                    "cms_can_edit": cms_can_edit,
                }),
            )
    except TemplateDoesNotExist:
        if name.endswith("/index"):
            raise Http404()
        else:
            return render_template(request, name=name + "/index")



from django.core.urlresolvers import reverse
from django.template.loaders.app_directories import app_template_dirs
import os
import re


def get_cms_pages(base_dir="cms_lite", sub_dirs=[]):
    templates = []
    for app_template_dir in app_template_dirs:
        cms_lite_dir = os.path.join(app_template_dir, "cms_lite", *sub_dirs)
        for root, subFolders, files in os.walk(cms_lite_dir):
            templates.extend([
                reverse("cms_lite_page", args=[
                    re.sub(r"_", "-", re.sub(r"\/?index", "", re.sub(r"\.html$", "", os.path.relpath(os.path.join(root, f), cms_lite_dir))))
                ])
                for f in files
                if not f.startswith("_") and f.endswith(".html")
            ])
    return sorted(set(templates))



from django.contrib.sitemaps import Sitemap
from cms_lite.utils import get_cms_pages


class CMSLiteSitemap(Sitemap):
    changefreq = "monthly"

    def items(self):
        return get_cms_pages()

    def lastmod(self, obj):
        return None

    def location(self, obj):
        return obj

    def priority(self, obj):
        return (1.0 - obj.count("/") * 0.1)



from django import forms


class CmsPageForm(forms.Form):
    source = forms.CharField(
        help_text="Be careful. Mistakes as simple as unescaped HTML characters like < and > can easily break things.",
        widget=forms.Textarea(
            attrs={
                "class": "span6",
                "rows": "30",
            },
        )
    )



from setuptools import setup, find_packages

setup(
    name='django-cms-lite',
    version='2013.05.13.0',
    description='Simple Django CMS with very limited functionality.',
    long_description='Renders discovered HTML tempaltes as CMS pages.',
    author='Brad Beattie',
    author_email='bradbeattie@gmail.com',
    url='https://github.com/bradbeattie/django-cms-lite',
    license='BSD',
    packages=find_packages(),
    include_package_data=True,
    package_data = { '': ['README.rst'] },
    install_requires=['django'],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ]
)
